// VRML Generator
// (c) Justin Couch
//
// From Chapter 13: Late Night VRML 2.0 and Java
//
// The Group node dialog. Only needs to get the bounding box size
// and center as well as a DEF name.

package ui.dialogs;

import java.awt.*;
import ui.dialogs.VrmlBaseDialog;
import geometry.Group;
import ui.VrmlTree;
import VrmlScene;
import VrmlTypes;
import exceptions.NoSelectedNodeException;


public class GroupDialog extends VrmlBaseDialog
{
	private TextField	center_x, center_y, center_z;
	private TextField	size_x, size_y, size_z;

	public GroupDialog(Frame parent, VrmlTree tree, VrmlScene data)
	{
		super(parent, "Edit Group Node");

		vrml_data = data;
		screen_data = tree;

		content_panel.setLayout(new GridLayout(3, 1));

		// first the title
		content_panel.add(new Label("Bounding Box", Label.LEFT));

		// now the first row. On the left is the Label and on the right is
		// the 3 boxes for x, y and z, indicated by appropriate labels.
		Panel p1 = new Panel();
		p1.setLayout(new BorderLayout(15, 10));

		p1.add("West", new Label("Center", Label.LEFT));

		Panel p2 = new Panel();
		p2.setLayout(new GridLayout(1, 6));

		// the 3 components.
		center_x = new TextField("0", 4);
		center_y = new TextField("0", 4);
		center_z = new TextField("0", 4);

		p2.add(new Label("x: ", Label.RIGHT));
		p2.add(center_x);
		p2.add(new Label("y: ", Label.RIGHT));
		p2.add(center_y);
		p2.add(new Label("z: ", Label.RIGHT));
		p2.add(center_z);

		p1.add("East", p2);
		content_panel.add(p1);

		// The second row. Identical to the first with the exception that
		// we have changed a label over
		Panel p3 = new Panel();
		p3.setLayout(new BorderLayout(15, 10));

		p3.add("West", new Label("Size", Label.LEFT));

		Panel p4 = new Panel();
		p4.setLayout(new GridLayout(1, 6));

		// the 3 components.
		size_x = new TextField("-1", 4);
		size_y = new TextField("-1", 4);
		size_z = new TextField("-1", 4);

		p4.add(new Label("x: ", Label.RIGHT));
		p4.add(size_x);
		p4.add(new Label("y: ", Label.RIGHT));
		p4.add(size_y);
		p4.add(new Label("z: ", Label.RIGHT));
		p4.add(size_z);

		p3.add("East", p4);
		content_panel.add(p3);

		pack();
	}

	// read all the information back out of the panel and pass it
	// to the appropriate place.
	public boolean applyInformation()
	{
		String str;

		float[]	center = new float[3];
		float[] size = new float[3];

		Group group;

		center[0] = Float.valueOf(center_x.getText()).floatValue();
		center[1] = Float.valueOf(center_y.getText()).floatValue();
		center[2] = Float.valueOf(center_z.getText()).floatValue();

		size[0] = Float.valueOf(size_x.getText()).floatValue();
		size[1] = Float.valueOf(size_y.getText()).floatValue();
		size[2] = Float.valueOf(size_z.getText()).floatValue();

		// are we creating a default node? This test for a yes
		if((center[0] != 0) || (center[1] != 0) || (center[2] != 0) ||
		   (size[0] != -1) || (size[1] != -1) || (size[2] != -1))
			group = new Group(browser, center, size);
		else
			group = new Group(browser);

		System.out.println("Before string");

		str = name.getText();
		if(str.equals(""))
			group.name = null;
		else
			group.name = new String(name.getText());

		try
		{
			vrml_data.addNode(VrmlTypes.Group, group);
		}
		catch (NoSelectedNodeException e)
		{
			System.out.println("No node selected");
		}

		return false;
	}

}