// VRML Generator
// (c) Justin Couch
//
// From Chapter 13: Late Night VRML 2.0 and Java
//
// The container dialog for editing the properties of each node
// This should be subclassed to produce the desired dialog

package ui.dialogs;

import java.awt.*;
import VrmlScene;
import ui.VrmlTree;
import vrml.external.Browser;

public abstract class VrmlBaseDialog extends Dialog
{
	protected Browser browser;

	protected VrmlTree	screen_data;
	protected VrmlScene	vrml_data;

	protected Button ok;
	protected Button cancel;
	protected Button apply;

	protected TextField	name;
	protected Panel	content_panel;

	protected VrmlBaseDialog(Frame parent, String title)
	{
		super(parent, title, false);

		Panel button_panel = new Panel();
		Panel top_panel = new Panel();

		setLayout(new BorderLayout(15, 10));

		// create the buttons on the bottom
		ok = new Button("OK");
		cancel = new Button("Cancel");
		apply = new Button("Apply");

		button_panel.setLayout(new FlowLayout(FlowLayout.CENTER, 10, 10));
		button_panel.add(ok);
		button_panel.add(cancel);
		button_panel.add(apply);

		add("South", button_panel);

		// now create the top half of the dialog.
		top_panel.setLayout(new BorderLayout(15, 10));

		top_panel.add("West", new Label("Name"));

		name = new TextField(null, 20);
		top_panel.add("East", name);

		add("North", top_panel);

		content_panel = new Panel();
		add("Center", content_panel);
	}

	// this method needs to be implemented by the derived class.
	public abstract boolean applyInformation();

	public void setBrowser(Browser b)
	{
		browser = b;
	}

	// the event handler for the buttons.
	public boolean action(Event e, Object arg)
	{
		if(e.target == ok)
		{
			hide();
			return(applyInformation());
		}
		else if(e.target == cancel)
		{
			hide();
			return true;
		}
		else if(e.target == apply)
			return(applyInformation());
		else
			return false;
	}

}
